Learn R Programming

redistverse (version 0.1.2)

redistverse-package: redistverse: Easily Install and Load Redistricting Software

Description

logo

Easy installation, loading, and control of packages for redistricting data downloading, spatial data processing, simulation, analysis, and visualization. This package makes it easy to install and load multiple 'redistverse' packages at once. The 'redistverse' is developed and maintained by the Algorithm-Assisted Redistricting Methodology (ALARM) Project. For more details see https://alarm-redist.org.

Arguments

Author

Maintainer: Christopher T. Kenny ctkenny@proton.me (ORCID)

Authors:

Other contributors:

  • tidyverse contributors (attach code adapted from tidyverse.) [contributor]

See Also